@@ -1148,7 +1148,7 @@ class Client(commandServer, encrypt):
         if self.domain:
             foundMountRemote = isMount("/var/calculate/remote")
             if not foundMountRemote:
-                self.mountRemote();
+                self.mountRemote(byUserSync=True);
         # check on two session user login
         if self.isTwoSessionsUser(self.userName):
             return False
@@ -1831,8 +1831,8 @@ class Client(commandServer, encrypt):
 
     def restartDBus(self):
         """Restart D-Bus service"""
-        dbusDaemon = 'rc-service -i dbus'
-        existsDaemon = 'rc-service -e dbus'
+        dbusDaemon = '/sbin/rc-service -i dbus'
+        existsDaemon = '/sbin/rc-service -e dbus'
         # if exists dbus and running
         if os.system(existsDaemon) == 0 and \
             os.system(dbusDaemon + ' status &>/dev/null') == 0:
@@ -2108,7 +2108,7 @@ class Client(commandServer, encrypt):
                 os.rmdir(previousHome)
         return True
 
-    def mountRemote(self):
+    def mountRemote(self,byUserSync=False):
         """
         Mount remote domain resource for domain workstation.
 
@@ -2145,8 +2145,10 @@ class Client(commandServer, encrypt):
                 os.makedirs(pathRemote)
             if self.mountSambaRes(domain,"client",pwdRemote,
                                0,0,"remote",pathRemote) is False:
-                self.printWARNING(_("Failed to mount Samba resource [%s]")%\
-                                    "remote" + " ...")
+                if not byUserSync:
+                    self.printWARNING(
+                        _("Failed to mount Samba resource [%s]")%\
+                                        "remote" + " ...")
                 beforeRemoteAuth = self.clVars.Get('os_remote_auth')
                 # apply templates if current up-to-date
                 if not self.applyRelevanceTemplates():
